==> segment-wrapper-3.51.0-beta.0.tgz: package/lib/segmentWrapper.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _extends from "@babel/runtime/helpers/esm/extends";
var _ref2, _ref8, _ref12;
import _regeneratorRuntime from "@babel/runtime/regenerator";
// @ts-check

import { SEGMENT_ID_USER_WITHOUT_CONSENTS } from './middlewares/source/userTraits.js';
import { getAdobeMCVisitorID } from './adobeRepository.js';
import { getConfig } from './config.js';
import { checkAnalyticsGdprIsAccepted, getGdprPrivacyValue } from './tcf.js';
import { getXandrId } from './xandrRepository.js';

/* Default properties to be sent on all trackings */
var DEFAULT_PROPERTIES = {
  platform: 'web'
};

/* Disabled integrations when no GDPR Privacy Value is true */
export var INTEGRATIONS_WHEN_NO_CONSENTS = {
  All: false
};
export var INTEGRATIONS_WHEN_NO_CONSENTS_CMP_SUBMITTED = {
  All: true
};

/**
 * Get default properties using the constant and the window.__mpi object if available
 * @returns {{[key:string]: any}} Default properties to attach to track
 */
export var getDefaultProperties = function getDefaultProperties() {
  return _extends({}, DEFAULT_PROPERTIES, getConfig('defaultProperties'));
};

/**
 * Get all needed integrations depending on the gdprPrivacy value.
 * One of them is the AdobeMarketingCloudVisitorId for Adobe Analytics integration.
 * @param {object} param - Object with the gdprPrivacyValue and if it's a CMP Submitted event
 */
var getTrackIntegrations = function getTrackIntegrations(_x) {
  return (_ref2 = _ref2 || _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var gdprPrivacyValue, event, isGdprAccepted, marketingCloudVisitorId, _yield$Promise$all, adobeAnalyticsIntegration, restOfIntegrations;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          gdprPrivacyValue = _ref.gdprPrivacyValue, event = _ref.event;
          isGdprAccepted = checkAnalyticsGdprIsAccepted(gdprPrivacyValue);
          marketingCloudVisitorId = null;
          if (!isGdprAccepted) {
            _context.next = 9;
            break;
          }
          ;
          _context.next = 7;
          return Promise.all([getAdobeMCVisitorID()]);
        case 7:
          _yield$Promise$all = _context.sent;
          marketingCloudVisitorId = _yield$Promise$all[0];
        case 9:
          adobeAnalyticsIntegration = marketingCloudVisitorId ? {
            marketingCloudVisitorId: marketingCloudVisitorId
          } : true;
          restOfIntegrations = getRestOfIntegrations({
            isGdprAccepted: isGdprAccepted,
            event: event
          }); // if we don't have the user consents we remove all the integrations but Adobe Analytics
          return _context.abrupt("return", _extends({}, restOfIntegrations, {
            'Adobe Analytics': adobeAnalyticsIntegration,
            'Amazon Lambda': true
          }));
        case 12:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }))).apply(this, arguments);
};

/**
 * Get Rest of integrations depending on the gdprPrivacy value and if it's a CMP Submitted event
 * @param {object} param - Object with the isGdprAccepted and if it's a CMP Submitted event
 * @returns {object} integrations
 */
export var getRestOfIntegrations = function getRestOfIntegrations(_ref3) {
  var isGdprAccepted = _ref3.isGdprAccepted,
    event = _ref3.event;
  var isCMPSubmittedEvent = event === 'CMP Submitted';
  if (isCMPSubmittedEvent) {
    return INTEGRATIONS_WHEN_NO_CONSENTS_CMP_SUBMITTED;
  }
  return isGdprAccepted ? {} : INTEGRATIONS_WHEN_NO_CONSENTS;
};

/**
 * It returns externalIds to add to context
 *
 * @param {Object} param
 * @param {Object} param.context previous context
 * @param {String} param.xandrId xandrId to be included
 * @returns
 */
var getExternalIds = function getExternalIds(_ref4) {
  var context = _ref4.context,
    xandrId = _ref4.xandrId;
  var shouldSendXandrId = getConfig('sendXandrId') !== false;
  var isValidXandrId = xandrId && parseInt(xandrId) !== 0;
  if (!shouldSendXandrId || !isValidXandrId) {
    return {};
  }
  var SEGMENT_COLLECTION = 'users';
  var SEGMENT_ENCODING = 'none';
  var SEGMENT_TYPE = 'xandr_id';
  var externalIds = [].concat((context == null ? void 0 : context.externalIds) || [], [{
    collection: SEGMENT_COLLECTION,
    encoding: SEGMENT_ENCODING,
    id: xandrId,
    type: SEGMENT_TYPE
  }]);
  var uniqueExternalIds = externalIds.filter(function (_ref5, index) {
    var idFilter = _ref5.id,
      typeFilter = _ref5.type;
    return index === externalIds.findIndex(function (_ref6) {
      var idFind = _ref6.id,
        typeFind = _ref6.type;
      return idFilter === idFind && typeFilter === typeFind;
    });
  });
  return {
    externalIds: uniqueExternalIds
  };
};

/**
 * Get data like traits and integrations to be added to the context object
 * @param {object} context Context object with all the actual info
 * @returns {Promise<object>} New context with all the previous info and the new one
 */
export var decorateContextWithNeededData = function decorateContextWithNeededData(_x2) {
  return (_ref8 = _ref8 || _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(_ref7) {
    var _ref7$event, event, _ref7$context, context, gdprPrivacyValue, _ref9, gdprPrivacyValueAnalytics, gdprPrivacyValueAdvertising, isGdprAccepted, _yield$Promise$all2, integrations, xandrId;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) switch (_context2.prev = _context2.next) {
        case 0:
          _ref7$event = _ref7.event, event = _ref7$event === void 0 ? '' : _ref7$event, _ref7$context = _ref7.context, context = _ref7$context === void 0 ? {} : _ref7$context;
          _context2.next = 3;
          return getGdprPrivacyValue();
        case 3:
          gdprPrivacyValue = _context2.sent;
          _ref9 = gdprPrivacyValue || {}, gdprPrivacyValueAnalytics = _ref9.analytics, gdprPrivacyValueAdvertising = _ref9.advertising;
          isGdprAccepted = checkAnalyticsGdprIsAccepted(gdprPrivacyValue);
          _context2.next = 8;
          return Promise.all([getTrackIntegrations({
            gdprPrivacyValue: gdprPrivacyValue,
            event: event
          }), getXandrId({
            gdprPrivacyValueAdvertising: gdprPrivacyValueAdvertising
          })]);
        case 8:
          _yield$Promise$all2 = _context2.sent;
          integrations = _yield$Promise$all2[0];
          xandrId = _yield$Promise$all2[1];
          if (!isGdprAccepted) {
            context.anonymousId = SEGMENT_ID_USER_WITHOUT_CONSENTS;
          }
          return _context2.abrupt("return", _extends({}, context, !isGdprAccepted && {
            ip: '0.0.0.0'
          }, getExternalIds({
            context: context,
            xandrId: xandrId
          }), {
            gdpr_privacy: gdprPrivacyValueAnalytics,
            gdpr_privacy_advertising: gdprPrivacyValueAdvertising,
            integrations: _extends({}, context.integrations, integrations)
          }));
        case 13:
        case "end":
          return _context2.stop();
      }
    }, _callee2);
  }))).apply(this, arguments);
};

/**
 * The track method lets you record any actions your users perform.
 * @param {string} event The name of the event you’re tracking
 * @param {object} [properties] A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */
var track = function track(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }
  return new Promise(function (resolve) {
    var _ref10;
    var initTrack = function initTrack() {
      return (_ref10 = _ref10 || _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
        var _ref11;
        var newContext, newProperties, newCallback;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              _context4.next = 2;
              return decorateContextWithNeededData({
                context: context,
                event: event
              });
            case 2:
              newContext = _context4.sent;
              /**
               * @deprecated Now we use `defaultContextProperties` middleware
               * and put the info on the context object
               */
              newProperties = _extends({}, getDefaultProperties(), properties);
              newCallback = function newCallback() {
                return (_ref11 = _ref11 || _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
                  var _yield$Promise$all3,
                    gdprPrivacyValue,
                    _args3 = arguments;
                  return _regeneratorRuntime.wrap(function _callee3$(_context3) {
                    while (1) switch (_context3.prev = _context3.next) {
                      case 0:
                        if (callback) callback.apply(void 0, _args3); // eslint-disable-line n/no-callback-literal
                        _context3.next = 3;
                        return Promise.all([getGdprPrivacyValue()]);
                      case 3:
                        _yield$Promise$all3 = _context3.sent;
                        gdprPrivacyValue = _yield$Promise$all3[0];
                        if (checkAnalyticsGdprIsAccepted(gdprPrivacyValue)) {
                          resolve.apply(void 0, _args3);
                        } else {
                          resolve();
                        }
                      case 6:
                      case "end":
                        return _context3.stop();
                    }
                  }, _callee3);
                }))).apply(this, arguments);
              };
              window.analytics.track(event, newProperties, _extends({}, newContext, {
                context: {
                  integrations: _extends({}, newContext.integrations)
                }
              }), newCallback);
            case 6:
            case "end":
              return _context4.stop();
          }
        }, _callee4);
      }))).apply(this, arguments);
    };
    initTrack();
  });
};

/**
 * Associate your users and their actions to a recognizable userId and traits.
 * @param {string} userId Id to identify the user.
 * @param {object} traits A dictionary of traits you know about the user, like their email or name.
 * @param {object} [options] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */
var identify = function identify(_x3, _x4, _x5, _x6) {
  return (_ref12 = _ref12 || _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5(userId, traits, options, callback) {
    var gdprPrivacyValue;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) switch (_context5.prev = _context5.next) {
        case 0:
          _context5.next = 2;
          return getGdprPrivacyValue();
        case 2:
          gdprPrivacyValue = _context5.sent;
          if (!checkAnalyticsGdprIsAccepted(gdprPrivacyValue)) {
            _context5.next = 5;
            break;
          }
          return _context5.abrupt("return", window.analytics.identify(userId, traits, options, callback));
        case 5:
        case "end":
          return _context5.stop();
      }
    }, _callee5);
  }))).apply(this, arguments);
};

/**
 * Record whenever a user sees a page of your website, along with any optional properties about the page.
 * @param {string} event The name of the event you’re tracking
 * @param {object=} properties A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */
var page = function page(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }
  // we put a flag on context to know this track is a page
  context.isPageTrack = true;
  // just call track again but the with the proper context
  return track(event, properties, context, callback);
};

/**
 * Resets the id, including anonymousId, and clear traits for the currently identified user and group.
 * NOTE: Only clears the cookies and localStorage set by analytics.
 * @returns {Promise}
 */
var reset = function reset() {
  return Promise.resolve(window.analytics.reset());
};
export default {
  page: page,
  identify: identify,
  track: track,
  reset: reset
};

==> segment-wrapper-3.53.0-beta.0.tgz: package/lib/segmentWrapper.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _extends from "@babel/runtime/helpers/esm/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
// @ts-check

import { SEGMENT_ID_USER_WITHOUT_CONSENTS } from './middlewares/source/userTraits.js';
import { getAdobeMCVisitorID } from './adobeRepository.js';
import { getConfig } from './config.js';
import { checkAnalyticsGdprIsAccepted, getGdprPrivacyValue } from './tcf.js';
import { getXandrId } from './xandrRepository.js';

/* Default properties to be sent on all trackings */
var DEFAULT_PROPERTIES = {
  platform: 'web'
};

/* Disabled integrations when no GDPR Privacy Value is true */
export var INTEGRATIONS_WHEN_NO_CONSENTS = {
  All: false
};
export var INTEGRATIONS_WHEN_NO_CONSENTS_CMP_SUBMITTED = {
  All: true
};

/**
 * Get default properties using the constant and the window.__mpi object if available
 * @returns {{[key:string]: any}} Default properties to attach to track
 */
export var getDefaultProperties = function getDefaultProperties() {
  return _extends({}, DEFAULT_PROPERTIES, getConfig('defaultProperties'));
};

/**
 * Get all needed integrations depending on the gdprPrivacy value.
 * One of them is the AdobeMarketingCloudVisitorId for Adobe Analytics integration.
 * @param {object} param - Object with the gdprPrivacyValue and if it's a CMP Submitted event
 */
var getTrackIntegrations = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var gdprPrivacyValue, event, isGdprAccepted, marketingCloudVisitorId, adobeAnalyticsIntegration, restOfIntegrations;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          gdprPrivacyValue = _ref.gdprPrivacyValue, event = _ref.event;
          isGdprAccepted = checkAnalyticsGdprIsAccepted(gdprPrivacyValue); // if (isGdprAccepted) {
          _context.next = 4;
          return getAdobeMCVisitorID();
        case 4:
          marketingCloudVisitorId = _context.sent;
          // }
          adobeAnalyticsIntegration = marketingCloudVisitorId ? {
            marketingCloudVisitorId: marketingCloudVisitorId
          } : true;
          restOfIntegrations = getRestOfIntegrations({
            isGdprAccepted: isGdprAccepted,
            event: event
          }); // if we don't have the user consents we remove all the integrations but Adobe Analytics
          return _context.abrupt("return", _extends({}, restOfIntegrations, {
            'Adobe Analytics': adobeAnalyticsIntegration,
            'Amazon Lambda': true
          }));
        case 8:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return function getTrackIntegrations(_x) {
    return _ref2.apply(this, arguments);
  };
}();

/**
 * Get Rest of integrations depending on the gdprPrivacy value and if it's a CMP Submitted event
 * @param {object} param - Object with the isGdprAccepted and if it's a CMP Submitted event
 * @returns {object} integrations
 */
export var getRestOfIntegrations = function getRestOfIntegrations(_ref3) {
  var isGdprAccepted = _ref3.isGdprAccepted,
    event = _ref3.event;
  var isCMPSubmittedEvent = event === 'CMP Submitted';
  if (isCMPSubmittedEvent) {
    return INTEGRATIONS_WHEN_NO_CONSENTS_CMP_SUBMITTED;
  }
  return isGdprAccepted ? {} : INTEGRATIONS_WHEN_NO_CONSENTS;
};

/**
 * It returns externalIds to add to context
 *
 * @param {Object} param
 * @param {Object} param.context previous context
 * @param {String} param.xandrId xandrId to be included
 * @returns
 */
var getExternalIds = function getExternalIds(_ref4) {
  var context = _ref4.context,
    xandrId = _ref4.xandrId;
  var shouldSendXandrId = getConfig('sendXandrId') !== false;
  var isValidXandrId = xandrId && parseInt(xandrId) !== 0;
  if (!shouldSendXandrId || !isValidXandrId) {
    return {};
  }
  var SEGMENT_COLLECTION = 'users';
  var SEGMENT_ENCODING = 'none';
  var SEGMENT_TYPE = 'xandr_id';
  var externalIds = [].concat((context == null ? void 0 : context.externalIds) || [], [{
    collection: SEGMENT_COLLECTION,
    encoding: SEGMENT_ENCODING,
    id: xandrId,
    type: SEGMENT_TYPE
  }]);
  var uniqueExternalIds = externalIds.filter(function (_ref5, index) {
    var idFilter = _ref5.id,
      typeFilter = _ref5.type;
    return index === externalIds.findIndex(function (_ref6) {
      var idFind = _ref6.id,
        typeFind = _ref6.type;
      return idFilter === idFind && typeFilter === typeFind;
    });
  });
  return {
    externalIds: uniqueExternalIds
  };
};

/**
 * Get data like traits and integrations to be added to the context object
 * @param {object} context Context object with all the actual info
 * @returns {Promise<object>} New context with all the previous info and the new one
 */
export var decorateContextWithNeededData = /*#__PURE__*/function () {
  var _ref8 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(_ref7) {
    var _ref7$event, event, _ref7$context, context, gdprPrivacyValue, _ref9, gdprPrivacyValueAnalytics, gdprPrivacyValueAdvertising, isGdprAccepted, _yield$Promise$all, integrations, xandrId, _context$integrations;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) switch (_context2.prev = _context2.next) {
        case 0:
          _ref7$event = _ref7.event, event = _ref7$event === void 0 ? '' : _ref7$event, _ref7$context = _ref7.context, context = _ref7$context === void 0 ? {} : _ref7$context;
          _context2.next = 3;
          return getGdprPrivacyValue();
        case 3:
          gdprPrivacyValue = _context2.sent;
          _ref9 = gdprPrivacyValue || {}, gdprPrivacyValueAnalytics = _ref9.analytics, gdprPrivacyValueAdvertising = _ref9.advertising;
          isGdprAccepted = checkAnalyticsGdprIsAccepted(gdprPrivacyValue);
          _context2.next = 8;
          return Promise.all([getTrackIntegrations({
            gdprPrivacyValue: gdprPrivacyValue,
            event: event
          }), getXandrId({
            gdprPrivacyValueAdvertising: gdprPrivacyValueAdvertising
          })]);
        case 8:
          _yield$Promise$all = _context2.sent;
          integrations = _yield$Promise$all[0];
          xandrId = _yield$Promise$all[1];
          if (!isGdprAccepted) {
            // context.anonymousId = SEGMENT_ID_USER_WITHOUT_CONSENTS
            context.integrations = _extends({}, (_context$integrations = context.integrations) != null ? _context$integrations : {}, {
              Personas: false,
              Webhooks: true,
              Webhook: true
            });
          }
          return _context2.abrupt("return", _extends({}, context, getExternalIds({
            context: context,
            xandrId: xandrId
          }), {
            gdpr_privacy: gdprPrivacyValueAnalytics,
            gdpr_privacy_advertising: gdprPrivacyValueAdvertising,
            integrations: _extends({}, context.integrations, integrations)
          }));
        case 13:
        case "end":
          return _context2.stop();
      }
    }, _callee2);
  }));
  return function decorateContextWithNeededData(_x2) {
    return _ref8.apply(this, arguments);
  };
}();

/**
 * The track method lets you record any actions your users perform.
 * @param {string} event The name of the event you’re tracking
 * @param {object} [properties] A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */
var track = function track(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }
  return new Promise(function (resolve) {
    var initTrack = /*#__PURE__*/function () {
      var _ref10 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
        var newContext, newProperties, newCallback;
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              _context4.next = 2;
              return decorateContextWithNeededData({
                context: context,
                event: event
              });
            case 2:
              newContext = _context4.sent;
              /**
               * @deprecated Now we use `defaultContextProperties` middleware
               * and put the info on the context object
               */
              newProperties = _extends({}, getDefaultProperties(), properties);
              newCallback = /*#__PURE__*/function () {
                var _ref11 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
                  var _yield$Promise$all2,
                    gdprPrivacyValue,
                    _args3 = arguments;
                  return _regeneratorRuntime.wrap(function _callee3$(_context3) {
                    while (1) switch (_context3.prev = _context3.next) {
                      case 0:
                        if (callback) callback.apply(void 0, _args3); // eslint-disable-line n/no-callback-literal
                        _context3.next = 3;
                        return Promise.all([getGdprPrivacyValue()]);
                      case 3:
                        _yield$Promise$all2 = _context3.sent;
                        gdprPrivacyValue = _yield$Promise$all2[0];
                        if (checkAnalyticsGdprIsAccepted(gdprPrivacyValue)) {
                          resolve.apply(void 0, _args3);
                        } else {
                          resolve();
                        }
                      case 6:
                      case "end":
                        return _context3.stop();
                    }
                  }, _callee3);
                }));
                return function newCallback() {
                  return _ref11.apply(this, arguments);
                };
              }();
              window.analytics.track(event, newProperties, _extends({}, newContext, {
                context: {
                  integrations: _extends({}, newContext.integrations)
                }
              }), newCallback);
            case 6:
            case "end":
              return _context4.stop();
          }
        }, _callee4);
      }));
      return function initTrack() {
        return _ref10.apply(this, arguments);
      };
    }();
    initTrack();
  });
};

/**
 * Associate your users and their actions to a recognizable userId and traits.
 * @param {string} userId Id to identify the user.
 * @param {object} traits A dictionary of traits you know about the user, like their email or name.
 * @param {object} [options] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */
var identify = /*#__PURE__*/function () {
  var _ref12 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5(userId, traits, options, callback) {
    var gdprPrivacyValue;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) switch (_context5.prev = _context5.next) {
        case 0:
          _context5.next = 2;
          return getGdprPrivacyValue();
        case 2:
          gdprPrivacyValue = _context5.sent;
          if (!checkAnalyticsGdprIsAccepted(gdprPrivacyValue)) {
            _context5.next = 5;
            break;
          }
          return _context5.abrupt("return", window.analytics.identify(userId, traits, options, callback));
        case 5:
        case "end":
          return _context5.stop();
      }
    }, _callee5);
  }));
  return function identify(_x3, _x4, _x5, _x6) {
    return _ref12.apply(this, arguments);
  };
}();

/**
 * Record whenever a user sees a page of your website, along with any optional properties about the page.
 * @param {string} event The name of the event you’re tracking
 * @param {object=} properties A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */
var page = function page(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }
  // we put a flag on context to know this track is a page
  context.isPageTrack = true;
  // just call track again but the with the proper context
  return track(event, properties, context, callback);
};

/**
 * Resets the id, including anonymousId, and clear traits for the currently identified user and group.
 * NOTE: Only clears the cookies and localStorage set by analytics.
 * @returns {Promise}
 */
var reset = function reset() {
  return Promise.resolve(window.analytics.reset());
};
export default {
  page: page,
  identify: identify,
  track: track,
  reset: reset
};
